@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 # shortcuts
 #  os and distros
@@ -547,7 +547,10 @@ sub mapping {
      [cpanmod => 'Curses',
       # ncurses.h is included in FreeBSD base install
       [like_debian,
-       [package => 'libncurses5-dev']]],
+       [package => 'libncurses5-dev']],
+      [like_fedora,
+       [package => 'ncurses-devel']],
+     ],
 
      [cpanmod => 'Curses::UI::Mousehandler::GPM',
       [like_debian,
@@ -622,7 +625,7 @@ sub mapping {
        [package => 'mysql-connector-c | mysql57-client | mysql56-client | mysql55-client | mariadb101-client | mariadb100-client | mariadb55-client | percona56-client | percona55-client']],
       [like_debian,
        [package => 'libmysqlclient-dev']],
-      [like_debian,
+      [like_fedora,
        [package => 'mariadb-devel']],
       [os_darwin,
        [package => 'mysql-connector-c | mysql']],
@@ -679,6 +682,13 @@ sub mapping {
       # no package for debian
      ],
 
+     [cpanmod => 'Device::USB',
+      [like_debian,
+       [package => 'libusb-dev']],
+      [like_fedora,
+       [package => 'libusb-devel']], # but testsuite segfaults
+     ],
+
      [cpanmod => 'Device::Velleman::K8055::libk8055',
       [os_freebsd,
        [package => 'libk8055']],
@@ -1363,7 +1373,8 @@ sub mapping {
      [cpanmod => 'JavaScript::V8',
       [os_freebsd,
        [package => 'v8']],
-      # XXX what about debian?
+      [like_debian,
+       [package => 'libv8-dev']],
       [like_fedora,
        [package => 'v8-devel']], # but problems with Devel-CheckLib and compilation errors
       [os_darwin,
@@ -1480,9 +1491,10 @@ sub mapping {
 	[package => []], # not available before jessie
        ],
        [package => 'liblmdb-dev']],
-      ## does not work, maybe Makefile.PL needs better detection?
-      #[os_darwin,
-      # [package => 'lmdb']],
+      [like_fedora,
+       [package => 'lmdb-devel']],
+      [os_darwin,
+       [package => 'lmdb']],
      ],
 
      [cpanmod => 'Locale::gettext', # gettext distribution
@@ -1637,6 +1649,8 @@ sub mapping {
        [package => ['dbus', 'pkgconf']]],
       [like_debian,
        [package => ['libdbus-1-dev', 'pkg-config | pkgconf']]],
+      [like_fedora,
+       [package => ['dbus-devel', 'pkgconfig']]],
       [os_darwin,
        [package => 'dbus']],
      ],
@@ -1831,6 +1845,11 @@ sub mapping {
        # but does not work, lookup into wrong freetype directory
        [package => ['libftgl-dev', 'libfreetype6-dev']]]],
 
+     [cpanmod => 'OpenGL::Modern',
+      [like_fedora,
+       [package => 'mesa-libGLU-devel']],
+     ],
+
      [cpanmod => 'PAM',
       [like_debian,
        [package => 'libpam0g-dev']]],
